'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _spec_helper = require('./spec_helper.js');

var _spec_helper2 = _interopRequireDefault(_spec_helper);

var _index = require('./../index.js');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var should = _chai2.default.should();
var expect = _chai2.default.expect;
var ShouldStem = _spec_helper2.default.ShouldTransform;
var ShouldNotTransform = _spec_helper2.default.ShouldNotTransform;

// PENDING

describe("Akarata", function () {
	describe("covering the inflectional particles", function () {
		it("'kah'", function () {
			ShouldStem(_index2.default.stem, 'manakah', 'mana');
			ShouldStem(_index2.default.stem, 'bukukah', 'buku');
		});

		it("'lah'", function () {
			ShouldStem(_index2.default.stem, 'adalah', 'ada');
		});

		it("'pun'", function () {
			ShouldStem(_index2.default.stem, 'bagaimanapun', 'bagaimana');
		});
	});

	describe("covering the inflectional possessive pronouns", function () {
		it("'ku'", function () {
			ShouldStem(_index2.default.stem, 'bukuku', 'buku');
		});

		it("'mu'", function () {
			ShouldStem(_index2.default.stem, 'rumahmu', 'rumah');
		});

		it("'nya'", function () {
			ShouldStem(_index2.default.stem, 'cintanya', 'cinta');
		});
	});

	describe("covering the first order of derivational prefixes", function () {
		it("'meng'", function () {
			ShouldStem(_index2.default.stem, 'mengukur', 'ukur');
		});

		it("'meny'", function () {
			ShouldStem(_index2.default.stem, 'menyapu', 'sapu');
		});

		it("'men'", function () {
			ShouldStem(_index2.default.stem, 'menduga', 'duga');
			ShouldStem(_index2.default.stem, 'menuduh', 'tuduh');
		});

		it("'me'", function () {
			ShouldStem(_index2.default.stem, 'menikah', 'nikah');
		});

		describe("'mem' followed by 'p'", function () {
			it("'mem'", function () {
				ShouldStem(_index2.default.stem, 'memilih', 'pilih');
				ShouldStem(_index2.default.stem, 'memilah', 'pilah');
				ShouldStem(_index2.default.stem, 'memuji', 'puji');
				ShouldStem(_index2.default.stem, 'memakai', 'pakai');
			});
		});

		it("'mem'", function () {
			ShouldStem(_index2.default.stem, 'membaca', 'baca');
			ShouldStem(_index2.default.stem, 'membantu', 'bantu');
		});

		it("'me'", function () {
			ShouldStem(_index2.default.stem, 'melayang', 'layang');
			ShouldStem(_index2.default.stem, 'merusak', 'rusak');
		});

		it("'peng'", function () {
			ShouldStem(_index2.default.stem, 'pengukur', 'ukur');
		});

		it("'peny'", function () {
			ShouldStem(_index2.default.stem, 'penyalin', 'salin');
		});

		it("'pen'", function () {
			ShouldStem(_index2.default.stem, 'penasehat', 'nasehat');
			ShouldStem(_index2.default.stem, 'penarik', 'tarik');
		});

		describe("'pem' followed by p", function () {
			it("'pem'", function () {
				ShouldStem(_index2.default.stem, 'pemilih', 'pilih');
				ShouldStem(_index2.default.stem, 'pemilah', 'pilah');
				ShouldStem(_index2.default.stem, 'pemuji', 'puji');
			});
		});

		it("'pem'", function () {
			ShouldStem(_index2.default.stem, 'pembaca', 'baca');
			ShouldStem(_index2.default.stem, 'pembicara', 'bicara');
		});

		it("'di'", function () {
			ShouldStem(_index2.default.stem, 'diukur', 'ukur');
			ShouldStem(_index2.default.stem, 'dilihat', 'lihat');
		});

		it("'ter'", function () {
			ShouldStem(_index2.default.stem, 'terindah', 'indah');
			ShouldStem(_index2.default.stem, 'terhebat', 'hebat');
			ShouldStem(_index2.default.stem, 'terukur', 'ukur');
			ShouldStem(_index2.default.stem, 'tersapu', 'sapu');
		});

		it("'ter'", function () {
			ShouldStem(_index2.default.stem, 'kekasih', 'kasih');
			ShouldStem(_index2.default.stem, 'kemana', 'mana');
		});
	});

	describe("covering the second order of derivational suffixes", function () {
		it("'ber'", function () {
			ShouldStem(_index2.default.stem, 'berlari', 'lari');
		});

		it("'bel'", function () {
			ShouldStem(_index2.default.stem, 'belajar', 'ajar');
		});

		it("'be'", function () {
			ShouldStem(_index2.default.stem, 'bekerja', 'kerja');
		});

		it("'per'", function () {
			ShouldStem(_index2.default.stem, 'perjelas', 'jelas');
		});

		it("'pel'", function () {
			ShouldStem(_index2.default.stem, 'pelajar', 'ajar');
		});

		it("'pe'", function () {
			ShouldStem(_index2.default.stem, 'pekerja', 'kerja');
			ShouldStem(_index2.default.stem, 'pelari', 'lari');
		});
	});

	describe("covering the derivational suffixes", function () {
		it("'kan'", function () {
			ShouldStem(_index2.default.stem, 'tarikkan', 'tarik');
			ShouldStem(_index2.default.stem, 'ambilkan', 'ambil');
		});

		it("'an'", function () {
			ShouldStem(_index2.default.stem, 'makanan', 'makan');
			ShouldStem(_index2.default.stem, 'sarapan', 'sarap');
		});

		it("'i'", function () {
			ShouldStem(_index2.default.stem, 'ajari', 'ajar');
			ShouldStem(_index2.default.stem, 'cermati', 'cermat');
		});
	});
});