'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _stemmer_utility = require('./../lib/stemmer_utility.js');

var _stemmer_utility2 = _interopRequireDefault(_stemmer_utility);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var should = _chai2.default.should();
var expect = _chai2.default.expect;

describe("stemmerUtility", function () {
	it("should available", function () {
		expect(_stemmer_utility2.default).to.exist;
	});

	var word = 'asldkamsdo';
	var prefix = 'asld';
	var suffix = 'amsdo';

	describe("the word starts with prefix", function () {
		it("that have different letters from the prefix should return false", function () {
			_stemmer_utility2.default.isStartsWith(word, 3, 'ber').should.be.false;
		});
	});

	describe("that have the same letters with the word's first letters", function () {
		it("by exactly prefix length should be true", function () {
			_stemmer_utility2.default.isStartsWith(word, prefix.length, prefix).should.be.true;
		});

		it("by more than prefix length should still be true", function () {
			_stemmer_utility2.default.isStartsWith(word, prefix.length + 1, prefix).should.be.true;
		});

		it("by less than prefix length should still be false", function () {
			_stemmer_utility2.default.isStartsWith(word, prefix.length - 1, prefix).should.be.false;
		});
	});

	describe("the word ends with suffix", function () {
		it("that have different letters from the suffix should return false", function () {
			_stemmer_utility2.default.isEndsWith(word, 3, 'abc').should.be.false;
		});

		describe("that have the same letters with the word's last letters", function () {
			it("by exactly suffix length should be true", function () {
				_stemmer_utility2.default.isEndsWith(word, suffix.length, suffix).should.be.true;
			});

			it("by more than suffix length should still be true", function () {
				_stemmer_utility2.default.isEndsWith(word, suffix.length + 1, suffix).should.be.true;
			});

			it("by less than suffix length should still be false", function () {
				_stemmer_utility2.default.isEndsWith(word, suffix.length - 1, suffix).should.be.false;
			});
		});
	});
});